@@ -93,10 +93,10 @@ def create_video(list_comp_data, path_video, job_id):
         while max_real_duration < 60*2/3 and cnt_real_duration<2 and cnt_effect_vid>1:
             max_real_duration*=2
             cnt_real_duration+=1
-        tmp_path = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) +"-final-vid.avi"
-        tmp_path_maked_loop = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + "-final-vid.avi"
+        tmp_path = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) +"-final-vid.mp4"
+        tmp_path_maked_loop = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + "-final-vid.mp4"
         final_clip = CompositeVideoClip(arr_composite).subclip(0, max_real_duration)
-        final_clip.write_videofile(tmp_path, fps=24, codec='libx264', audio=False, logger=logger)
+        final_clip.write_videofile(tmp_path, bitrate='4M', fps=24, codec='libx264', audio=False, logger=logger)
         final_clip.close()
         if cnt_effect_vid > 1:
             final_clip = VideoFileClip(tmp_path, audio=False)
@@ -104,7 +104,7 @@ def create_video(list_comp_data, path_video, job_id):
             if cross > 3:
                 cross = 3
             clip = make_loopable.make_loopable(final_clip, cross)
-            clip.write_videofile(tmp_path_maked_loop, fps=24, codec='libx264', audio=False, logger=logger)
+            clip.write_videofile(tmp_path_maked_loop, bitrate='4M', fps=24, codec='libx264', audio=False, logger=logger)
             clip.close()
             final_clip.close()
         else:
