@@ -2,6 +2,7 @@ import youtube_dl, requests
 from bgeditor.common.utils import get_dir, download_file,normal_audio
 from bgeditor.dao.FFmpeg import create_loop_audio_times
 import uuid,json, shutil,os
+from moviepy.editor import *
 def download_audio(url,ext='mp3'):
     file_name = str(uuid.uuid4()) + "." + ext
     rs = get_dir('download') + file_name
@@ -24,13 +25,33 @@ def create_compilation_songs(data):
     try:
         for song in arr_songs:
             try:
-                if song['type'] == 3:#youtube
-                    song['local']=download_audio(song['url'])
-                if song['type'] == 8:#direct
-                    song['local']=download_file(song['url'])
-                if song['type'] == 7:#deezer
-                    song_info=requests.get("http://api.automusic.win/deezer/track/get/"+song['url']).json()
+                arr_tmp=song['url'].split(":")
+                if arr_tmp[0] == "youtube":#youtube
+                    song['local']=download_audio(arr_tmp[1])
+                if arr_tmp[0] == "direct":#direct
+                    song['local']=download_file(arr_tmp[1])
+                if arr_tmp[0] == "deezer":#deezer
+                    song_info=requests.get("http://source.automusic.win/deezer/track/get/"+arr_tmp[1], timeout=180).json()
                     song['local']=download_file(song_info['url_128'])
+                if arr_tmp[0] == "spotify":  # spotify
+                    arr_song_info = requests.get("http://source.automusic.win/spotify/track/get/" + arr_tmp[1], timeout=180).json()
+                    if len(arr_song_info)>0:
+                        deezer_id=arr_song_info[0]['deezer_id']
+                        if int(deezer_id)>0:
+                            song_info = requests.get("http://source.automusic.win/deezer/track/get/" + deezer_id, timeout=180).json()
+                            song['local'] = download_file(song_info['url_128'])
+
+                #after download song, re-check song
+                try:
+                    audio_test=AudioFileClip(song['local'])
+                    audioduration=audio_test.duration
+                    audio_test.close()
+                    if audioduration < 1:
+                        continue
+                except:
+                    continue
+                    pass
+
                 if len(arr_songs) > 1:
                     song['local']=normal_audio(song['local'])
                 if song['repeat'] > 1:
